# puhdistusalue

Puhdistusalue (Finnish for clean area here meaning purge range).

[![license](https://img.shields.io/github/license/sthagen/puhdistusalue.svg?style=flat)](https://github.com/sthagen/puhdistusalue/blob/default/LICENSE)
[![version](https://img.shields.io/pypi/v/puhdistusalue.svg?style=flat)](https://pypi.python.org/pypi/puhdistusalue/)
[![downloads](https://img.shields.io/pypi/dm/puhdistusalue.svg?style=flat)](https://pypi.python.org/pypi/puhdistusalue/)
[![wheel](https://img.shields.io/pypi/wheel/puhdistusalue.svg?style=flat)](https://pypi.python.org/pypi/puhdistusalue/)
[![supported-versions](https://img.shields.io/pypi/pyversions/puhdistusalue.svg?style=flat)](https://pypi.python.org/pypi/puhdistusalue/)
[![supported-implementations](https://img.shields.io/pypi/implementation/puhdistusalue.svg?style=flat)](https://pypi.python.org/pypi/puhdistusalue/)

Purge monotonically named files in folders keeping range endpoints.

## Status

Experimental

*Note*: Within a folder, only the ordering and the min-max membership to its content identity range determines to keep a file.

More info needed?

... read the source, Luke.

**Note**: The default branch is `default`.
